@@ -1,13 +1,13 @@
 import os
 import traceback
-import logging
 
 import hypertrace.agent.filter
 from hypertrace.agent.filter.registry import TYPE_HTTP, TYPE_RPC
 from opentelemetry.trace import Span
 from traceableai.config.config import Config
+from hypertrace.agent.custom_logger import get_custom_logger # pylint:disable=C0413,C0411,C0412
 
-logger = logging.getLogger(__name__)
+logger = get_custom_logger(__name__)
 
 _LIBTRACEABLE_AVAILABLE = False
 _NOT_BODY = False
@@ -42,7 +42,7 @@ class Traceable(hypertrace.agent.filter.Filter):
             self.libtraceable_config = _create_libtraceable_config()
             p_libtraceable = _libtraceable.ffi.new("traceable_libtraceable*")
             result_code = _libtraceable.lib.traceable_new_libtraceable(
-                self.libtraceable_config[0], p_libtraceable)
+                self.libtraceable_config, p_libtraceable)
             self.libtraceable_available = (
                 result_code == _libtraceable.lib.TRACEABLE_SUCCESS)
             if self.libtraceable_available:
@@ -172,34 +172,32 @@ def _create_libtraceable_config():
     if traceable_config.blocking_config.debug_log.value is True:
         should_debug = 1
 
-    libtraceable_config = _libtraceable.ffi.new(
-        "traceable_libtraceable_config*")
+    libtraceable_config = _libtraceable.lib.init_libtraceable_config()
 
     libtraceable_config.log_config.mode = should_debug
 
+    # If blocking is disabled we will never attempt to initialize the traceable filter
+    # so we can safely set to 1 here
+    libtraceable_config.blocking_config.enabled = 1
+
     traceable_opa = traceable_config.opa
     opa_server_url = _libtraceable.ffi.new(
         "char[]", f"{traceable_opa.endpoint.value}".encode('ascii'))
 
-    libtraceable_config.blocking_config.enabled = 1
+    opa_enabled = (1 if traceable_opa.enabled.value is True else 0)
+    libtraceable_config.blocking_config.opa_config.enabled = opa_enabled
     libtraceable_config.blocking_config.opa_config.opa_server_url = opa_server_url
     libtraceable_config.blocking_config.opa_config.log_to_console = 1
-    libtraceable_config.blocking_config.opa_config.skip_verify = 0
     libtraceable_config.blocking_config.opa_config.debug_log = should_debug
     libtraceable_config.blocking_config.opa_config.min_delay = traceable_opa.poll_period_seconds.value
     libtraceable_config.blocking_config.opa_config.max_delay = traceable_opa.poll_period_seconds.value
-    libtraceable_config.blocking_config.opa_config.logging_dir = _libtraceable.ffi.new(
-        "char[]", "".encode('ascii'))
-    libtraceable_config.blocking_config.opa_config.logging_file_prefix = _libtraceable.ffi.new(
-        "char[]", "".encode('ascii'))
-    libtraceable_config.blocking_config.opa_config.cert_file = _libtraceable.ffi.new(
-        "char[]", "".encode('ascii'))
 
     modsecurity_enabled = (
         1 if traceable_config.blocking_config.modsecurity.enabled.value is True else 0)
+
     libtraceable_config.blocking_config.modsecurity_config.enabled = modsecurity_enabled
 
-    rb_enabled = 1 if traceable_config.blocking_config.region_blocking.enabled else 0
+    rb_enabled = 1 if traceable_config.blocking_config.region_blocking.enabled.value is True else 0
     libtraceable_config.blocking_config.rb_config.enabled = rb_enabled
 
     libtraceable_config.blocking_config.evaluate_body = (
